how to import module/library

--> from rubpy import Bot

How to activate the robot?

from rubpy import Bot


auth = Bot("your auth")

guid = "your group guid"

bot.sendMessage(guid, "hello")

For more training and to see the document, visit @rubika_library in Telegram